summaryrefslogtreecommitdiff
path: root/libs/pbd/pbd/demangle.h
diff options
context:
space:
mode:
Diffstat (limited to 'libs/pbd/pbd/demangle.h')
-rw-r--r--libs/pbd/pbd/demangle.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libs/pbd/pbd/demangle.h b/libs/pbd/pbd/demangle.h
index 1ca2925fd0..98b8bf787c 100644
--- a/libs/pbd/pbd/demangle.h
+++ b/libs/pbd/pbd/demangle.h
@@ -54,17 +54,17 @@ namespace PBD
}
/**
- * @param a mangled symbol/name
+ * @param symbol a mangled symbol/name
* @return a demangled symbol/name
*/
- LIBPBD_API std::string symbol_demangle(const std::string&);
+ LIBPBD_API std::string demangle_symbol(const std::string& symbol);
/**
* @param a string containing a mangled symbol/name
* @return a string with the mangled symbol/name replaced with a demangled
* name
*/
- LIBPBD_API std::string demangle(const std::string&);
+ LIBPBD_API std::string demangle(const std::string& str);
} // namespace
@@ -54,17 +54,17 @@ namespace PBD
/**
- * @param a string containing a mangled symbol/name
+ * @param str a string containing a mangled symbol/name
* @return a string with the mangled symbol/name replaced with a demangled
* name